pub fn coverage_rows_to_batch(
rows: &[CatalogCoverageRow],
) -> Result<RecordBatch>Expand description
Errors
Returns an error if the coverage rows cannot be encoded with the canonical Arrow schema.
pub fn coverage_rows_to_batch(
rows: &[CatalogCoverageRow],
) -> Result<RecordBatch>Returns an error if the coverage rows cannot be encoded with the canonical Arrow schema.