pub fn last_data_timestamp(rows: &[CatalogCoverageRow]) -> Option<u64>Expand description
Returns the latest timestamp still covered by data after applying deletions.
Empty coverage rows do not represent stored data and are skipped.
pub fn last_data_timestamp(rows: &[CatalogCoverageRow]) -> Option<u64>Returns the latest timestamp still covered by data after applying deletions.
Empty coverage rows do not represent stored data and are skipped.